@@ -7,7 +7,7 @@
  *	This sample code is distributed under the same terms and conditions of the CommonC++ library.
  */
 
-#include <cc++/socket.h>
+#include <cc++/socketport.h>
 
 #ifdef	CCXX_NAMESPACES
 using namespace ost;
