@@ -335,9 +335,9 @@ protected:
 	 *
 	 * @return true if current filename is accepted.
 	 * @param file path to examine
-	 * @param stat info of type, date, etc.
+	 * @param ino info of type, date, etc.
 	 */
-	virtual bool filter(const char *path, struct stat *ino);
+	virtual bool filter(const char *file, struct stat *ino);
 
 public:
 	/**
@@ -345,23 +345,23 @@ public:
 	 * prefix.  A maximum subdirectory depth is also specified.
 	 *
 	 * @param prefix to start walk.
-	 * @param maximum subdirectory.
+	 * @param maxdepth subdirectory depth to examine.
 	 */
-	DirTree(const char *prefix, unsigned depth);
+	DirTree(const char *prefix, unsigned maxdepth);
 
 	/**
 	 * Construct an un-opened directory tree of a known maximum depth
 	 *
-	 * @param maximum subdirectory.
+	 * @param maxdepth subdirectory subdirectory depth.
  	 */
-	DirTree(unsigned depth);
+	DirTree(unsigned maxdepth);
 
 	virtual ~DirTree();
 
 	/**
 	 * Open a directory tree path.
 	 *
-	 * @param path to open.
+	 * @param prefix directory path to open.
 	 */
 	void open(const char *prefix);
 
@@ -386,7 +386,7 @@ public:
 	 * filter rather than externally by calling getPath().
 	 *
 	 * @return number of files and directories examined.
-	 * @param path to examine.
+	 * @param prefix directory path to examine.
 	 */
 	unsigned perform(const char *prefix);
 };
@@ -451,7 +451,7 @@ protected:
 	 * Post an extended string error message.
 	 *
 	 * @return errExtended.
-	 * @param errstr error string.
+	 * @param err error string.
 	 */
 	inline Error error(char *err)
 		{return error(errExtended, err);};
