@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2003 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of Common C++.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// The exception is that, if you link the Common C++ library with other files
-// to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
-//
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
 //
-// If you write modifications of your own for Common C++, it is your choice
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 #include <cc++/config.h>
 #include <cc++/exception.h>
@@ -192,6 +189,10 @@ Date::Date(int year, unsigned month, unsigned day)
 	toJulian(year, month, day);
 }
 
+void Date::update(void)
+{
+}
+
 bool Date::isValid(void) const
 {
 	if(julian == 0x7fffffffl)
@@ -493,6 +494,10 @@ int Time::getSecond(void) const
 	return num();
 }
 
+void Time::update(void)
+{
+}
+
 void Time::setTime(char *str, size_t size)
 {
 	int sec = 00;
@@ -550,28 +555,28 @@ long Time::getValue(void) const
 Time& Time::operator++()
 {
 	++seconds;
-	Update();
+	update();
 	return *this;
 }
 
 Time& Time::operator--()
 {
 	--seconds;
-	Update();
+	update();
 	return *this;
 }
 
 Time& Time::operator+=(const int val)
 {
 	seconds += val;
-	Update();
+	update();
 	return *this;
 }
 
 Time& Time::operator-=(const int val)
 {
 	seconds -= val;
-	Update();
+	update();
 	return *this;
 }
 
@@ -642,7 +647,7 @@ Time operator+(const Time &time1, const Time &time2)
 {
 	Time t;
 	t.seconds = time1.seconds + time2.seconds;
-	t.Update();
+	t.update();
 	return t;
 }
 
@@ -650,7 +655,7 @@ Time operator-(const Time &time1, const Time &time2)
 {
 	Time t;
 	t.seconds = time1.seconds - time2.seconds;
-	t.Update();
+	t.update();
 	return t;
 }
 
@@ -658,7 +663,7 @@ Time operator+(const Time &time, const int val)
 {
 	Time t = time;
 	t.seconds += val;
-	t.Update();
+	t.update();
 	return t;
 }
 
@@ -666,7 +671,7 @@ Time operator+(const int val, const Time &time)
 {
 	Time t = time;
 	t.seconds += val;
-	t.Update();
+	t.update();
 	return t;
 }
 
@@ -674,7 +679,7 @@ Time operator-(const Time &time, const int val)
 {
 	Time t = time;
 	t.seconds -= val;
-	t.Update();
+	t.update();
 	return t;
 }
 
@@ -682,7 +687,7 @@ Time operator-(const int val, const Time &time)
 {
 	Time t = time;
 	t.seconds -= val;
-	t.Update();
+	t.update();
 	return t;
 }
 
@@ -820,7 +825,8 @@ Datetime& Datetime::operator+=(const Datetime &datetime)
 {
 	seconds += datetime.seconds;
 	julian += datetime.julian; 
-	Update();
+	Date::update();
+	Time::update();
 	return *this;
 }
 
@@ -828,21 +834,24 @@ Datetime& Datetime::operator-=(const Datetime &datetime)
 {
 	seconds -= datetime.seconds;
 	julian -= datetime.julian; 
-	Update();
+	Date::update();
+	Time::update();
 	return *this;
 }
 
 Datetime& Datetime::operator+=(const Time &time)
 {
 	seconds += time.getValue();
-	Update();
+	Date::update();
+	Time::update();
 	return *this;
 }
 
 Datetime& Datetime::operator-=(const Time &time)
 {
 	seconds -= time.getValue();
-	Update();
+	Date::update();
+	Time::update();
 	return *this;
 }
 
