@@ -461,7 +461,8 @@ ssize_t Socket::writeData(const void *Source, size_t Size, timeout_t timeout)
           return (-1);
         }
       Size -= nstat;
-      Slide += Size;
+      Slide += nstat;
+	
 
       if (Size <= 0)
         break;
@@ -1330,7 +1331,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 		return;
 	}
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
         int opt = 1;
         setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt,
                 (socklen_t)sizeof(opt));
@@ -1433,7 +1434,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 		addr = (struct sockaddr *)&addr4;
 	}
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
         int opt = 1;
         setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt,
                 (socklen_t)sizeof(opt));
@@ -1477,7 +1478,7 @@ Socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)
 	peer.ipv4.sin_family = AF_INET;
 	peer.ipv4.sin_addr = getaddress(ia);
 	peer.ipv4.sin_port = htons(port);
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
 	int opt = 1;
 	setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, (socklen_t)sizeof(opt));
 #endif
@@ -1499,7 +1500,7 @@ Socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP)
 	peer.ipv6.sin6_family = AF_INET6;
 	peer.ipv6.sin6_addr = getaddress(ia);
 	peer.ipv6.sin6_port = htons(port);
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
 	int opt = 1;
 	setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, (socklen_t)sizeof(opt));
 #endif
@@ -1698,7 +1699,7 @@ Socket::Error UDPSocket::disconnect(void)
         addr.sin_family = AF_UNSPEC;
 #else
         addr.sin_family = AF_INET;
-        addr.sin_addr.s_addr = INADDR_NONE;
+	memset(&addr.sin_addr, 0, sizeof(addr.sin_addr));
 #endif  
         if(::connect(so, (sockaddr *)&addr, len))
                 return connectError();
@@ -1800,8 +1801,6 @@ void UDPSocket::setPeer(const char *name)
 	char namebuf[128], *cp;
 	struct servent *svc;
 	tpport_t port;
-	struct sockaddr *addr;
-	socklen_t alen;
 
         snprintf(namebuf, sizeof(namebuf), "%s", name);
         cp = strrchr(namebuf, '/');
@@ -1992,7 +1991,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 		return;
 	}
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
         int opt = 1;
         setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, 
                 (socklen_t)sizeof(opt));
@@ -2072,7 +2071,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 	IPV4Address ia(name);
 	addr.sin_addr = getaddress(ia);
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
         int opt = 1;    
         setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, 
 		(socklen_t)sizeof(opt));
@@ -2108,7 +2107,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 	addr.sin_addr = getaddress(ia);
 	addr.sin_port = htons(port);
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
 	int opt = 1;
 	setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, (socklen_t)sizeof(opt));
 #endif
@@ -2188,7 +2187,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 		return;
 	}
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
         int opt = 1;
         setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, 
                 (socklen_t)sizeof(opt));
@@ -2267,7 +2266,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 	IPV6Address ia(name);
 	addr.sin6_addr = getaddress(ia);
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
         int opt = 1;    
         setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, 
 		(socklen_t)sizeof(opt));
@@ -2304,7 +2303,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 	addr.sin6_addr = getaddress(ia);
 	addr.sin6_port = htons(port);
 
-#if defined(SO_REUSEADDR) && !defined(WIN32)
+#if defined(SO_REUSEADDR)
 	int opt = 1;
 	setsockopt(so, SOL_SOCKET, SO_REUSEADDR, (char *)&opt, (socklen_t)sizeof(opt));
 #endif
