@@ -1765,7 +1765,9 @@ int SysTime::getTimeOfDay(struct timeval *tp)
     // We could use _ftime(), but it is not available on WinCE.
     // (WinCE also lacks time.h)
     // Note also that the average error of _ftime is around 20 ms :)
-    time(&temp.tv_sec);
+    time_t now;
+    time(&now);
+    temp.tv_sec = (long)now;
     temp.tv_usec = (GetTickCount() % 1000) * 1000;
 	memcpy(tp, &temp, sizeof(struct timeval));
 #else
